# CrashOps plugin for Flutter - Sample project

[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

This Flutter plugin helps to bridge your app with the CrashOps native SDK.
CrashOps SDK helps you monitor your app's crashes and Flutter errors.

## Installation

Easiest to install, it's a "plug n' play" plugin. All you need to do is add `crashops_flutter` dependency and the SDK will automatically start monitoring on each application launch.

Required changes in your `pubspec.yaml` file:
```
dependencies:
  flutter:
    sdk: flutter
...
  crashops_flutter: any
...
```

## Usage



### Catch errors

To catch errors from your Flutter app, edit your `main()` method as follows:
```dart
void main() {
  CrashOps.instance.run(app: MyApp(), withCatchingErrors: true, onError: (e, stacktrace) {
    print("Caught error from Flutter / Dart:\nError: $e\nStack Trace: $stacktrace");
  });
}
```

### Custom configurations
```dart
class _MyAppState extends State<MyApp> {
  // It's not mandatory to put those configurations inside a State.
  // It may also be in the "main()" function.
  final CrashOps crashOps = CrashOps();

  ...

  @override
  void initState() {
    super.initState();

    // If you're willing to create logs in debug
    crashOps.isEnabledInDebugMode = true;
    // If you wish to upload logs to CrashOps servers
    crashOps.setClientId(
        "the-client-id-you-received-from-crashops-customer-support");
    // If you wish to add more details in each log
    crashOps.setMetadata({"yo": "that's my awesome app!"});
  }

  ...

}
```

## Don't have [Flutter](https://flutter.dev/) yet?

For help getting started with Flutter, view their
[online documentation](https://flutter.dev/docs), which offers tutorials,
samples, guidance on mobile development, and a full API reference.

## Acknowledgments

[iOS](https://github.com/CrashOps/iOS-SDK/): [KSCrash](https://github.com/kstenerud/KSCrash) library.

[Android](https://github.com/CrashOps/Android-SDK/): [retrofit](https://square.github.io/retrofit/).

[Flutter](https://pub.dev/packages/crashops_flutter): https://pub.dev/flutter



### TODO
Become production ready :)

Our SDK is still under development, stay tuned: [CrashOps.com](https://www.crashops.com/)
